@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: aggregates.lisp 10141 2004-11-09 02:29:43Z kevin $
+;;;; $Id: aggregates.lisp 10393 2005-04-06 17:42:24Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -226,18 +226,30 @@ of the enum-name name, separator-string, and field-name"
       (declare (fixnum i))
       (setf (aref a i) (uffi:deref-array s '(:array :unsigned-byte) i)))))
 
+#+sbcl
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (sb-ext:without-package-locks
+      (defvar *system-copy-fn* (if (fboundp (intern "COPY-FROM-SYSTEM-AREA" "SB-KERNEL"))
+				   (intern "COPY-FROM-SYSTEM-AREA" "SB-KERNEL")
+				   (intern "COPY-UB8-FROM-SYSTEM-AREA" "SB-KERNEL")))
+    (defconstant +system-copy-offset+ (if (fboundp (intern "COPY-FROM-SYSTEM-AREA" "SB-KERNEL"))
+					  (* sb-vm:vector-data-offset sb-vm:n-word-bits)
+					  0))
+    (defconstant +system-copy-multiplier+ (if (fboundp (intern "COPY-FROM-SYSTEM-AREA" "SB-KERNEL"))
+					      sb-vm:n-byte-bits
+					      1))))
+  
+
 #+sbcl
 (defun convert-from-foreign-usb8 (s len)
   (let ((sap (sb-alien:alien-sap s)))
     (declare (type sb-sys:system-area-pointer sap))
     (locally
-	(declare (optimize (speed 3) (safety 0)))
-      (let ((result (make-array len :element-type '(unsigned-byte 8))))
-	(sb-kernel:copy-from-system-area sap 0
-					 result (* sb-vm:vector-data-offset
-						   sb-vm:n-word-bits)
-					 (* len sb-vm:n-byte-bits))
-	result))))
+     (declare (optimize (speed 3) (safety 0)))
+     (let ((result (make-array len :element-type '(unsigned-byte 8))))
+       (funcall *system-copy-fn* sap 0 result +system-copy-offset+
+		(* len +system-copy-multiplier+))
+       result))))
 
 #+cmu
 (defun convert-from-foreign-usb8 (s len)
