@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: strings.lisp 10140 2004-11-09 02:14:43Z kevin $
+;;;; $Id: strings.lisp 10396 2005-04-13 18:43:34Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -301,47 +301,47 @@ that LW/CMU automatically converts strings from c-calls."
 
 #+(and sbcl (not sb-unicode))
 (defun sbcl-naturalize-cstring (sap &key length (null-terminated-p t))
-  (declare (type sb-sys:system-area-pointer sap))
+  (declare (type sb-sys:system-area-pointer sap)
+	   (type (or null fixnum) length))
   (locally
-      (declare (optimize (speed 3) (safety 0)))
-    (let ((null-terminated-length
-	   (when null-terminated-p
-	     (loop
-		 for offset of-type fixnum upfrom 0
-		 until (zerop (sb-sys:sap-ref-8 sap offset))
-		 finally (return offset)))))
-      (if length
-	  (if (and null-terminated-length
-		   (> (the fixnum length) (the fixnum null-terminated-length)))
-	      (setq length null-terminated-length))
-	(setq length null-terminated-length)))
-    (let ((result (make-string length)))
-      (sb-kernel:copy-from-system-area sap 0
-				    result (* sb-vm:vector-data-offset
-					      sb-vm:n-word-bits)
-				    (* length sb-vm:n-byte-bits))
-      result)))
+   (declare (optimize (speed 3) (safety 0)))
+   (let ((null-terminated-length
+	  (when null-terminated-p
+	    (loop
+	     for offset of-type fixnum upfrom 0
+	     until (zerop (sb-sys:sap-ref-8 sap offset))
+	     finally (return offset)))))
+     (if length
+	 (if (and null-terminated-length
+		  (> (the fixnum length) (the fixnum null-terminated-length)))
+	     (setq length null-terminated-length))
+       (setq length null-terminated-length)))
+   (let ((result (make-string length)))
+       (funcall *system-copy-fn* sap 0 result +system-copy-offset+
+		(* length +system-copy-multiplier+))
+       result)))
 
 #+(and sbcl sb-unicode)
 (defun sbcl-naturalize-cstring (sap &key length (null-terminated-p t))
-  (declare (type sb-sys:system-area-pointer sap))
+  (declare (type sb-sys:system-area-pointer sap)
+	   (type (or null fixnum) length))
   (locally
-      (declare (optimize (speed 3) (safety 0)))
-      (cond
-        (null-terminated-p
-	 (let ((casted (sb-alien:cast
-			(sb-alien:sap-alien sap (* char)) sb-alien:c-string)))
-	   (if length
-	       (copy-seq (subseq casted 0 length))
-	       (copy-seq casted))))
-        (t
-         (let ((result (make-string length)))
-	   ;; this will not work in sb-unicode
-           (sb-kernel:copy-from-system-area sap 0
-                                            result (* sb-vm:vector-data-offset
-                                                      sb-vm:n-word-bits)
-                                            (* length sb-vm:n-byte-bits))
-           result)))))
+   (declare (optimize (speed 3) (safety 0)))
+   (cond
+    (null-terminated-p
+     (let ((casted (sb-alien:cast (sb-alien:sap-alien sap (* char))
+				  #+sb-unicode sb-alien:utf8-string
+				  #-sb-unicode sb-alien:c-string)))
+       (if length
+	   (copy-seq (subseq casted 0 length))
+	 (copy-seq casted))))
+    (t
+     (let ((result (make-string length)))
+       ;; this will not work in sb-unicode
+       (funcall *system-copy-fn* sap 0 result +system-copy-offset+
+		(* length +system-copy-multiplier+))
+       result)))))
+
 
 (eval-when (:compile-toplevel :load-toplevel :execute)
    (def-function "strlen"
