@@ -7,7 +7,7 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: foreign-loader.lisp 9343 2004-05-13 10:23:40Z kevin $
+;;;; $Id: foreign-loader.lisp 10271 2005-01-23 00:28:49Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -25,7 +25,7 @@
 	  #+(or macosx darwin)
 	  "z"
 	  (list (pathname-directory *load-pathname*)
-		"/usr/local/lib/" #+64bit "/usr/lib64/"
+		"/usr/local/lib/" #+(or 64bit x86-64) "/usr/lib64/"
 		"/usr/lib/" "/zlib/"))
 	 :module "zlib" 
 	 :supporting-libraries '("c"))
@@ -33,7 +33,7 @@
   
 (unless (uffi:load-foreign-library 
 	 (uffi:find-foreign-library
-	  "uffi-c-test" 
+	  '(#+(or 64bit x86-64) "uffi-c-test64" "uffi-c-test") 
 	  (list (pathname-directory *load-truename*)
 		"/usr/lib/uffi/"
 		"/home/kevin/debian/src/uffi/tests/"))
