@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: structs.lisp 7061 2003-09-07 06:34:45Z kevin $
+;;;; $Id: structs.lisp 10350 2005-03-02 19:25:59Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
 ;;;;
@@ -29,3 +29,8 @@
     t)
   t)
 
+(deftest structs.2
+    (progn
+      (uffi:def-foreign-type foo-struct (:struct foo))
+      t)
+  t)
