@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Mar 2002
 ;;;;
-;;;; $Id: union.lisp 9396 2004-05-18 22:38:52Z kevin $
+;;;; $Id: union.lisp 10350 2005-03-02 19:25:59Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
 ;;;;
@@ -49,4 +49,23 @@
 (deftest union.3 (plusp (uffi:get-slot-value *u* 'tunion1 'uint)) t)
 
 
+(uffi:def-union foo-u
+    (bar :pointer-self))
+
+(uffi:def-foreign-type foo-u-ptr (* foo-u))
+
+;; tests that compilation worked
+(deftest unions.4 
+  (with-foreign-object (p 'foo-u)
+    t)
+  t)
+
+(deftest unions.5
+    (progn
+      (uffi:def-foreign-type foo-union (:union foo-u))
+      t)
+  t)
+
+
+
 
